@@ -1,5 +1,5 @@
 """
 """
 from .api import \
-    parse, is_pattern, build, expand, match, get, update, remove, apply, \
+    parse, is_pattern, build, expand, match, get, has, update, remove, apply, \
     register, transform, assemble, ANY, is_inverted
